ul#django_cradmin_messages {
  margin: 0;
}

#django_cradmin_messages_standalone_wrapper {
  ul#django_cradmin_messages {
    .alert {
      font-size: @font-size-large;
      &.alert-dismissable button.close,
      .django-cradmin-alert-loadspinner {
        top: 1px;
      }
    }
  }
}
