<a href="{{ url }}"
        {% if dom_id %}
            id="{{ dom_id }}"
        {% endif %}
        class="btn btn-{{ buttonclass }} btn-sm"
        {% for attribute in attributes %}
            {{ attribute|safe }}
        {% endfor %}
        >
    {% if icon %}
        <span class="{{ icon }}"></span>
    {% endif %}
    {{ label }}
</a>
