{% extends "django_cradmin/standalone-base.django.html" %}
{% comment %}
    Extends the standalone-base template to provide a layout
    suitable for pages with a single purpose such as login,
    reset password, accept invite, etc.

    ## Usage

    ```
    {% extends "django_cradmin/standalone-base.django.html" %}
    {% load crispy_forms_tags %}
    {% load i18n %}

    {% block pageheader-inner %}
        <h1>My cool page</h1>
    {% endblock pageheader-inner %}

    {% block content %}
        <div class="container">
        </div>
    {% endblock content %}
    ```
{% endcomment %}

{% block body %}
    {% block messages %}
        <div id="django_cradmin_messages_standalone_wrapper">
            {% include "django_cradmin/include/messages.django.html" %}
        </div>
    {% endblock messages %}

    <div id="django_cradmin_focusedlayout_wrapper"
            class="{% block wrapperclass %}django-cradmin-focusedpage-wrapper{% endblock wrapperclass %}">
        {% block pageheader %}
            <div class="page-header">
                {% block pageheader-inner %}{% endblock pageheader-inner %}
            </div>
        {% endblock pageheader %}

        <div id="django_cradmin_focusedlayout_content" class="django-cradmin-focusedpage-content">
            {% block content %}{% endblock content %}
        </div>
    </div>
{% endblock body %}
